'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _nodeFetch = require('node-fetch');

var _nodeFetch2 = _interopRequireDefault(_nodeFetch);

var _fetchCookie = require('fetch-cookie');

var _fetchCookie2 = _interopRequireDefault(_fetchCookie);

var _cheerio = require('cheerio');

var cheerio = _interopRequireWildcard(_cheerio);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fetch = (0, _fetchCookie2.default)(_nodeFetch2.default);

var lensdumpScraper = {
  /**
   * Scrapes data from an URL
   * @param {String} url - URL to scrape data from
   * @returns - Body/data of the URL
   */
  getImagesFromAlbumUrl: async function getImagesFromAlbumUrl(albumUrl) {
    var html = await this.getHtmlContent(albumUrl); // Getting the HTML from the album-URL
    var imageUrls = await this.getImagesFromAlbumHtml(html); // Getting the image-URLs from the album-HTML

    return imageUrls;
  },

  /**
   * Scrapes data from an URL
   * @param {String} url - URL to scrape data from
   * @returns - Body/data of the URL
   */
  getHtmlContent: async function getHtmlContent(url) {
    var response = await fetch(url); // Getting the HTML-data from the url
    var body = await response.text();

    return body;
  },

  /**
   * Gets the full-res image-URL from a lower-res Lensdump image-URL
   * @param {string} lowResImgUrl - The low-res image-URL
   * @returns {string} The higher-res image-URL
   */
  getHigherResImgUrl: function getHigherResImgUrl(lowResImgUrl) {
    return lowResImgUrl.replace('.md', '');
  },


  /**
   * Gets the image-URLs from the body/HTML provided
   * @param {Object} html - HTML/Body
   * @returns scraped image-URLs
   */
  getImagesFromAlbumHtml: async function getImagesFromAlbumHtml(html) {
    var imageUrls = [];
    var getHigherRes = this.getHigherResImgUrl;

    console.log('Fetching images from Album... ');

    var $ = await cheerio.load(html);
    var foundImageElements = $('.image-container img');

    $(foundImageElements).each(function (i, link) {
      var currUrl = $(this).attr('src'); // Getting the URL of the current img

      if (currUrl !== undefined) {
        currUrl = getHigherRes(currUrl);
        imageUrls.push(currUrl);
      }
    });

    if (imageUrls.length > 0) {
      console.log('OK\nImages found!');
    } else {
      console.log('No images found...');
    }

    return imageUrls;
  }
};

exports.default = lensdumpScraper;